@@ -2,8 +2,8 @@ from braintree.add_on import AddOn
 from braintree.add_on_gateway import AddOnGateway
 from braintree.address import Address
 from braintree.address_gateway import AddressGateway
-from braintree.android_pay_card import AndroidPayCard
 from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
+from braintree.android_pay_card import AndroidPayCard
 from braintree.apple_pay_card import ApplePayCard
 from braintree.braintree_gateway import BraintreeGateway
 from braintree.client_token import ClientToken
@@ -14,55 +14,53 @@ from braintree.credit_card_gateway import CreditCardGateway
 from braintree.credit_card_verification import CreditCardVerification
 from braintree.credit_card_verification_search import CreditCardVerificationSearch
 from braintree.customer import Customer
-from braintree.customer_search import CustomerSearch
 from braintree.customer_gateway import CustomerGateway
+from braintree.customer_search import CustomerSearch
+from braintree.descriptor import Descriptor
+from braintree.disbursement import Disbursement
 from braintree.discount import Discount
 from braintree.discount_gateway import DiscountGateway
-from braintree.descriptor import Descriptor
+from braintree.environment import Environment
 from braintree.error_codes import ErrorCodes
 from braintree.error_result import ErrorResult
 from braintree.errors import Errors
-from braintree.environment import Environment
+from braintree.europe_bank_account import EuropeBankAccount
+from braintree.us_bank_account import UsBankAccount
 from braintree.merchant import Merchant
 from braintree.merchant_account import MerchantAccount
-from braintree.merchant_account.business_details import BusinessDetails
-from braintree.merchant_account.funding_details import FundingDetails
-from braintree.merchant_account.individual_details import IndividualDetails
 from braintree.merchant_account_gateway import MerchantAccountGateway
+from braintree.partner_merchant import PartnerMerchant
+from braintree.payment_instrument_type import PaymentInstrumentType
 from braintree.payment_method import PaymentMethod
 from braintree.payment_method_nonce import PaymentMethodNonce
-from braintree.unknown_payment_method import UnknownPaymentMethod
-from braintree.payment_instrument_type import PaymentInstrumentType
 from braintree.paypal_account import PayPalAccount
-from braintree.partner_merchant import PartnerMerchant
 from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
 from braintree.resource_collection import ResourceCollection
 from braintree.risk_data import RiskData
-from braintree.three_d_secure_info import ThreeDSecureInfo
 from braintree.search import Search
 from braintree.settlement_batch_summary import SettlementBatchSummary
+from braintree.signature_service import SignatureService
+from braintree.status_event import StatusEvent
 from braintree.subscription import Subscription
 from braintree.subscription_gateway import SubscriptionGateway
-from braintree.subscription_status_event import SubscriptionStatusEvent
-from braintree.status_event import StatusEvent
-from braintree.testing_gateway import TestingGateway
-from braintree.transaction import Transaction
-from braintree.transaction_gateway import TransactionGateway
-from braintree.transaction_search import TransactionSearch
-from braintree.signature_service import SignatureService
-from braintree.disbursement import Disbursement
 from braintree.subscription_search import SubscriptionSearch
+from braintree.subscription_status_event import SubscriptionStatusEvent
 from braintree.successful_result import SuccessfulResult
+from braintree.testing_gateway import TestingGateway
+from braintree.three_d_secure_info import ThreeDSecureInfo
+from braintree.transaction import Transaction
 from braintree.transaction_amounts import TransactionAmounts
 from braintree.transaction_details import TransactionDetails
+from braintree.transaction_gateway import TransactionGateway
+from braintree.transaction_search import TransactionSearch
 from braintree.transparent_redirect import TransparentRedirect
 from braintree.transparent_redirect_gateway import TransparentRedirectGateway
+from braintree.unknown_payment_method import UnknownPaymentMethod
 from braintree.validation_error_collection import ValidationErrorCollection
+from braintree.venmo_account import VenmoAccount
 from braintree.version import Version
 from braintree.webhook_notification import WebhookNotification
 from braintree.webhook_notification_gateway import WebhookNotificationGateway
 from braintree.webhook_testing import WebhookTesting
 from braintree.webhook_testing_gateway import WebhookTestingGateway
-from braintree.europe_bank_account import EuropeBankAccount
-from braintree.venmo_account import VenmoAccount
