@@ -4,6 +4,6 @@ class AuthorizationError(BraintreeError):
     """
     Raised when the user does not have permission to complete the requested operation.
 
-    See https://developers.braintreepayments.com/ios+python/reference/general/exceptions#authorization-error
+    See https://developers.braintreepayments.com/reference/general/exceptions/python#authorization-error
     """
     pass
