@@ -27,6 +27,7 @@ from braintree.exceptions.not_found_error import NotFoundError
 from braintree.descriptor import Descriptor
 from braintree.risk_data import RiskData
 from braintree.three_d_secure_info import ThreeDSecureInfo
+from braintree.us_bank_account import UsBankAccount
 from braintree.facilitator_details import FacilitatorDetails
 from braintree.payment_instrument_type import PaymentInstrumentType
 
@@ -81,13 +82,56 @@ class Transaction(Resource):
         print(result.transaction.amount)
         print(result.transaction.order_id)
 
-    For more information on Transactions, see https://developers.braintreepayments.com/ios+python/reference/request/transaction/sale
+    For more information on Transactions, see https://developers.braintreepayments.com/reference/request/transaction/sale/python
 
     """
 
     def __repr__(self):
-        detail_list = ["amount", "credit_card", "payment_method_token", "customer_id"]
-        return super(Transaction, self).__repr__(detail_list)
+      detail_list = [
+        "id",
+        "additional_processor_response",
+        "amount",
+        "avs_error_response_code",
+        "avs_postal_code_response_code",
+        "avs_street_address_response_code",
+        "channel",
+        "created_at",
+        "credit_card_details",
+        "currency_iso_code",
+        "customer_id",
+        "cvv_response_code",
+        "disputes",
+        "escrow_status",
+        "gateway_rejection_reason",
+        "master_merchant_account_id",
+        "merchant_account_id",
+        "order_id",
+        "payment_instrument_type",
+        "payment_method_token",
+        "plan_id",
+        "processor_authorization_code",
+        "processor_response_code",
+        "processor_response_text",
+        "processor_settlement_response_code",
+        "processor_settlement_response_text",
+        "purchase_order_number",
+        "recurring",
+        "refund_id",
+        "refunded_transaction_id",
+        "service_fee_amount",
+        "settlement_batch_id",
+        "status",
+        "status_history",
+        "sub_merchant_account_id",
+        "subscription_id",
+        "tax_amount",
+        "tax_exempt",
+        "type",
+        "updated_at",
+        "voice_referral_number",
+      ]
+
+      return super(Transaction, self).__repr__(detail_list)
 
     class CreatedUsing(object):
         """
@@ -277,7 +321,7 @@ class Transaction(Resource):
 
 
     @staticmethod
-    def refund(transaction_id, amount=None):
+    def refund(transaction_id, amount_or_options=None):
         """
         Refunds an existing transaction.
 
@@ -287,7 +331,7 @@ class Transaction(Resource):
 
         """
 
-        return Configuration.gateway().transaction.refund(transaction_id, amount)
+        return Configuration.gateway().transaction.refund(transaction_id, amount_or_options)
 
 
     @staticmethod
@@ -348,6 +392,27 @@ class Transaction(Resource):
 
         return Configuration.gateway().transaction.submit_for_settlement(transaction_id, amount, params)
 
+    @staticmethod
+    def update_details(transaction_id, params={}):
+        """
+        Updates exisiting details for transaction submtted_for_settlement.
+
+        Requires the transaction id::
+
+            result = braintree.Transaction.update_details("my_transaction_id", {
+                "amount": "100.00",
+                "order_id": "123",
+                "descriptor": {
+                    "name": "123*123456789012345678",
+                    "phone": "3334445555",
+                    "url": "url.com"
+                }
+            )
+
+        """
+
+        return Configuration.gateway().transaction.update_details(transaction_id, params)
+
     @staticmethod
     def tr_data_for_credit(tr_data, redirect_url):
         """
@@ -421,10 +486,15 @@ class Transaction(Resource):
     def create_signature():
         return [
             "amount", "customer_id", "device_session_id", "fraud_merchant_id", "merchant_account_id", "order_id", "channel",
-            "payment_method_token", "purchase_order_number", "recurring", "shipping_address_id",
+            "payment_method_token", "purchase_order_number", "recurring", "transaction_source", "shipping_address_id",
             "device_data", "billing_address_id", "payment_method_nonce", "tax_amount",
             "shared_payment_method_token", "shared_customer_id", "shared_billing_address_id", "shared_shipping_address_id",
             "tax_exempt", "three_d_secure_token", "type", "venmo_sdk_payment_method_code", "service_fee_amount",
+            {
+                "risk_data": [
+                    "customer_browser", "customer_ip"
+                ]
+            },
             {
                 "credit_card": [
                     "token", "cardholder_name", "cvv", "expiration_date", "expiration_month", "expiration_year", "number"
@@ -449,6 +519,13 @@ class Transaction(Resource):
                     "postal_code", "region", "street_address"
                 ]
             },
+            {
+                "three_d_secure_pass_thru": [
+                    "eci_flag",
+                    "cavv",
+                    "xid"
+                ]
+            },
             {
                 "options": [
                     "add_billing_address_to_payment_method",
@@ -469,15 +546,24 @@ class Transaction(Resource):
                         "three_d_secure": [
                             "required"
                         ],
-                    },
-                    {
                         "amex_rewards": [
                             "request_id",
                             "points",
                             "currency_amount",
                             "currency_iso_code"
-                        ]
+                        ],
+                        "venmo_merchant_data": [
+                            "venmo_merchant_public_id",
+                            "originating_transaction_id",
+                            "originating_merchant_id"
+                        ],
                     },
+                    {
+                        "adyen": [
+                            "overwrite_brand",
+                            "selected_brand"
+                        ]
+                    }
                 ]
             },
             {"custom_fields": ["__any_key__"]},
@@ -500,7 +586,15 @@ class Transaction(Resource):
         return ["order_id", {"descriptor": ["name", "phone", "url"]}]
 
     @staticmethod
-    def submit_for_partial_settlement(transaction_id, amount):
+    def update_details_signature():
+        return ["amount", "order_id", {"descriptor": ["name", "phone", "url"]}]
+
+    @staticmethod
+    def refund_signature():
+        return ["amount", "order_id"]
+
+    @staticmethod
+    def submit_for_partial_settlement(transaction_id, amount, params={}):
         """
         Creates a partial settlement transaction for an authorized transaction
 
@@ -510,7 +604,7 @@ class Transaction(Resource):
 
         """
 
-        return Configuration.gateway().transaction.submit_for_partial_settlement(transaction_id, amount)
+        return Configuration.gateway().transaction.submit_for_partial_settlement(transaction_id, amount, params)
 
     def __init__(self, gateway, attributes):
         if "refund_id" in attributes:
@@ -532,6 +626,8 @@ class Transaction(Resource):
             self.paypal_details = PayPalAccount(gateway, attributes.pop("paypal"))
         if "europe_bank_account" in attributes:
             self.europe_bank_account_details = EuropeBankAccount(gateway, attributes.pop("europe_bank_account"))
+        if "us_bank_account" in attributes:
+            self.us_bank_account = UsBankAccount(gateway, attributes.pop("us_bank_account"))
         if "apple_pay" in attributes:
             self.apple_pay_details = ApplePayCard(gateway, attributes.pop("apple_pay"))
         if "coinbase_account" in attributes:
