@@ -1,5 +1,4 @@
 from tests.test_helper import *
-import base64
 import json
 import urllib
 import datetime
@@ -11,7 +10,7 @@ class TestClientTokenGenerate(unittest.TestCase):
     def test_allows_client_token_version_to_be_specified(self):
         client_token = ClientToken.generate({"version": 1})
         version = json.loads(client_token)["version"]
-        self.assertEqual(version, 1)
+        self.assertEqual(1, version)
 
     def test_error_in_generate_raises_value_error(self):
         self.assertRaises(ValueError, ClientToken.generate, {
@@ -30,14 +29,14 @@ class TestClientToken(unittest.TestCase):
             "shared_customer_identifier_type": "testing"
         })
 
-        status_code, response = http.get_cards()
-        self.assertEqual(status_code, 200)
+        status_code, _ = http.get_cards()
+        self.assertEqual(200, status_code)
 
     def test_client_token_version_defaults_to_two(self):
         client_token = TestHelper.generate_decoded_client_token()
         version = json.loads(client_token)["version"]
 
-        self.assertEqual(version, 2)
+        self.assertEqual(2, version)
 
     def test_can_pass_verify_card(self):
         config = Configuration.instantiate()
@@ -57,14 +56,14 @@ class TestClientToken(unittest.TestCase):
             "shared_customer_identifier_type": "testing"
         })
 
-        status_code, response = http.add_card({
+        status_code, _ = http.add_card({
             "credit_card": {
                 "number": "4000111111111115",
                 "expiration_month": "11",
                 "expiration_year": "2099",
             }
         })
-        self.assertEqual(status_code, 422)
+        self.assertEqual(422, status_code)
 
     def test_can_pass_make_default(self):
         config = Configuration.instantiate()
@@ -84,26 +83,26 @@ class TestClientToken(unittest.TestCase):
             "shared_customer_identifier_type": "testing"
         })
 
-        status_code, response = http.add_card({
+        status_code, _ = http.add_card({
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_month": "11",
                 "expiration_year": "2099",
             }
         })
-        self.assertEqual(status_code, 201)
+        self.assertEqual(201, status_code)
 
-        status_code, response = http.add_card({
+        status_code, _ = http.add_card({
             "credit_card": {
                 "number": "4005519200000004",
                 "expiration_month": "11",
                 "expiration_year": "2099",
             }
         })
-        self.assertEqual(status_code, 201)
+        self.assertEqual(201, status_code)
 
         customer = braintree.Customer.find(customer_id)
-        self.assertEqual(len(customer.credit_cards), 2)
+        self.assertEqual(2, len(customer.credit_cards))
         for credit_card in customer.credit_cards:
             if credit_card.bin == "400551":
                 self.assertTrue(credit_card.default)
@@ -123,14 +122,14 @@ class TestClientToken(unittest.TestCase):
             "shared_customer_identifier_type": "testing"
         })
 
-        status_code, response = http.add_card({
+        status_code, _ = http.add_card({
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_month": "11",
                 "expiration_year": "2099",
             }
         })
-        self.assertEqual(status_code, 201)
+        self.assertEqual(201, status_code)
 
         client_token = TestHelper.generate_decoded_client_token({
             "customer_id": customer_id,
@@ -140,17 +139,17 @@ class TestClientToken(unittest.TestCase):
         })
         authorization_fingerprint = json.loads(client_token)["authorizationFingerprint"]
         http.set_authorization_fingerprint(authorization_fingerprint)
-        status_code, response = http.add_card({
+        status_code, _ = http.add_card({
             "credit_card": {
                 "number": "4111111111111111",
                 "expiration_month": "11",
                 "expiration_year": "2099",
             }
         })
-        self.assertEqual(status_code, 422)
+        self.assertEqual(422, status_code)
 
         customer = braintree.Customer.find(customer_id)
-        self.assertEqual(len(customer.credit_cards), 1)
+        self.assertEqual(1, len(customer.credit_cards))
 
     def test_can_pass_sepa_params(self):
         result = braintree.Customer.create()
@@ -170,13 +169,10 @@ class TestClientToken(unittest.TestCase):
         })
         merchant_account_id = json.loads(client_token)["merchantAccountId"]
 
-        self.assertEqual(merchant_account_id, "my_merchant_account")
+        self.assertEqual("my_merchant_account", merchant_account_id)
 
+    @raises_with_regexp(Exception, "'Invalid keys: merchant_id'")
     def test_required_data_cannot_be_overridden(self):
-        try:
-            client_token = TestHelper.generate_decoded_client_token({
-                "merchant_id": "1234"
-            })
-            self.fail("Should have raised exception!")
-        except Exception as e:
-            self.assertEqual("'Invalid keys: merchant_id'", str(e))
+        TestHelper.generate_decoded_client_token({
+            "merchant_id": "1234"
+        })
