@@ -1,6 +1,5 @@
 import time
 from datetime import datetime
-from random import randint
 from tests.test_helper import *
 from braintree.test.credit_card_numbers import CreditCardNumbers
 from braintree.test.nonces import Nonces
@@ -15,21 +14,21 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertTrue(result.is_success)
         created_account = result.payment_method
-        self.assertEquals(created_account.__class__, PayPalAccount)
-        self.assertEquals(created_account.email, "jane.doe@example.com")
-        self.assertNotEquals(created_account.image_url, None)
+        self.assertEqual(PayPalAccount, created_account.__class__)
+        self.assertEqual("jane.doe@example.com", created_account.email)
+        self.assertNotEqual(created_account.image_url, None)
 
         found_account = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_account)
-        self.assertEquals(found_account.token, created_account.token)
-        self.assertEquals(found_account.customer_id, created_account.customer_id)
+        self.assertEqual(created_account.token, found_account.token)
+        self.assertEqual(created_account.customer_id, found_account.customer_id)
 
     def test_create_returns_validation_failures(self):
         http = ClientApiHttp.create()
         status_code, nonce = http.get_paypal_nonce({
             "options": {"validate": False}
         })
-        self.assertEquals(status_code, 202)
+        self.assertEqual(202, status_code)
         result = PaymentMethod.create({
             "payment_method_nonce": nonce
         })
@@ -73,7 +72,7 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertTrue(result.is_success)
-        self.assertEquals(token, result.payment_method.token)
+        self.assertEqual(token, result.payment_method.token)
 
     def test_create_with_paypal_one_time_nonce_fails(self):
         customer_id = Customer.create().customer.id
@@ -83,8 +82,9 @@ class TestPaymentMethod(unittest.TestCase):
         })
 
         self.assertFalse(result.is_success)
-        error_code = result.errors.for_object("paypal_account").on("base")[0].code
-        self.assertEquals(error_code, ErrorCodes.PayPalAccount.CannotVaultOneTimeUsePayPalAccount)
+        base_errors = result.errors.for_object("paypal_account").on("base")
+        self.assertEqual(1, len(base_errors))
+        self.assertEqual(ErrorCodes.PayPalAccount.CannotVaultOneTimeUsePayPalAccount, base_errors[0].code)
 
     def test_create_with_credit_card_nonce(self):
         http = ClientApiHttp.create()
@@ -94,7 +94,7 @@ class TestPaymentMethod(unittest.TestCase):
             "expirationYear": "2020",
             "options": {"validate": False}
         })
-        self.assertEquals(status_code, 202)
+        self.assertEqual(202, status_code)
 
         customer_id = Customer.create().customer.id
 
@@ -105,20 +105,20 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertTrue(result.is_success)
         created_credit_card = result.payment_method
-        self.assertEquals(created_credit_card.__class__, CreditCard)
-        self.assertEquals(created_credit_card.bin, "411111")
+        self.assertEqual(CreditCard, created_credit_card.__class__)
+        self.assertEqual("411111", created_credit_card.bin)
 
         found_credit_card = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_credit_card)
-        self.assertEquals(found_credit_card.token, created_credit_card.token)
-        self.assertEquals(found_credit_card.customer_id, created_credit_card.customer_id)
+        self.assertEqual(found_credit_card.token, created_credit_card.token)
+        self.assertEqual(found_credit_card.customer_id, created_credit_card.customer_id)
 
     def test_create_with_europe_bank_account_nonce(self):
         config = Configuration.instantiate()
         customer_id = Customer.create().customer.id
         token = TestHelper.generate_decoded_client_token({"customer_id": customer_id, "sepa_mandate_type": EuropeBankAccount.MandateType.Business})
         authorization_fingerprint = json.loads(token)["authorizationFingerprint"]
-        client_api =  ClientApiHttp(config, {
+        client_api = ClientApiHttp(config, {
             "authorization_fingerprint": authorization_fingerprint,
             "shared_customer_identifier": "fake_identifier",
             "shared_customer_identifier_type": "testing"
@@ -131,7 +131,7 @@ class TestPaymentMethod(unittest.TestCase):
             "billingAddress": {"region": "Hesse", "country_name": "Germany"}
         })
 
-        self.assertNotEquals(nonce, None)
+        self.assertNotEqual(nonce, None)
         result = PaymentMethod.create({
             "customer_id": customer_id,
             "payment_method_nonce": nonce
@@ -139,12 +139,12 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertTrue(result.is_success)
         self.assertNotEqual(result.payment_method.image_url, None)
-        self.assertEqual(result.payment_method.customer_id, customer_id)
+        self.assertEqual(customer_id, result.payment_method.customer_id)
         found_bank_account = PaymentMethod.find(result.payment_method.token)
 
         self.assertNotEqual(found_bank_account, None)
-        self.assertEquals(found_bank_account.bic, "DEUTDEFF")
-        self.assertEquals(found_bank_account.__class__, EuropeBankAccount)
+        self.assertEqual("DEUTDEFF", found_bank_account.bic)
+        self.assertEqual(EuropeBankAccount, found_bank_account.__class__)
 
     def test_create_with_fake_apple_pay_nonce(self):
         customer_id = Customer.create().customer.id
@@ -177,7 +177,7 @@ class TestPaymentMethod(unittest.TestCase):
         android_pay_card = result.payment_method
         self.assertIsInstance(android_pay_card, AndroidPayCard)
         self.assertNotEqual(android_pay_card.token, None)
-        self.assertEqual(android_pay_card.customer_id, customer_id)
+        self.assertEqual(customer_id, android_pay_card.customer_id)
         self.assertEqual(CreditCard.CardType.Discover, android_pay_card.virtual_card_type)
         self.assertEqual("1117", android_pay_card.virtual_card_last_4)
         self.assertEqual("Visa 1111", android_pay_card.source_description)
@@ -205,7 +205,7 @@ class TestPaymentMethod(unittest.TestCase):
         android_pay_card = result.payment_method
         self.assertIsInstance(android_pay_card, AndroidPayCard)
         self.assertNotEqual(android_pay_card.token, None)
-        self.assertEqual(android_pay_card.customer_id, customer_id)
+        self.assertEqual(customer_id, android_pay_card.customer_id)
         self.assertEqual(CreditCard.CardType.MasterCard, android_pay_card.virtual_card_type)
         self.assertEqual("4444", android_pay_card.virtual_card_last_4)
         self.assertEqual("MasterCard 4444", android_pay_card.source_description)
@@ -234,7 +234,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertIsInstance(amex_express_checkout_card, AmexExpressCheckoutCard)
         self.assertNotEqual(amex_express_checkout_card.token, None)
         self.assertTrue(amex_express_checkout_card.default)
-        self.assertEqual(amex_express_checkout_card.card_type, "American Express")
+        self.assertEqual("American Express", amex_express_checkout_card.card_type)
         self.assertRegexpMatches(amex_express_checkout_card.bin, r"\A\d{6}\Z")
         self.assertRegexpMatches(amex_express_checkout_card.expiration_month, r"\A\d{2}\Z")
         self.assertRegexpMatches(amex_express_checkout_card.expiration_year, r"\A\d{4}\Z")
@@ -242,7 +242,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertRegexpMatches(amex_express_checkout_card.card_member_expiry_date, r"\A\d{2}/\d{2}\Z")
         self.assertRegexpMatches(amex_express_checkout_card.source_description, r"\AAmEx \d{4}\Z")
         self.assertRegexpMatches(amex_express_checkout_card.image_url, r"\.png")
-        self.assertEqual(amex_express_checkout_card.customer_id, customer_id)
+        self.assertEqual(customer_id, amex_express_checkout_card.customer_id)
 
     def test_create_with_venmo_account_nonce(self):
         customer_id = Customer.create().customer.id
@@ -257,12 +257,39 @@ class TestPaymentMethod(unittest.TestCase):
 
         self.assertTrue(venmo_account.default)
         self.assertIsNotNone(venmo_account.token)
-        self.assertEqual(venmo_account.username, "venmojoe")
-        self.assertEqual(venmo_account.venmo_user_id, "Venmo-Joe-1")
-        self.assertEqual(venmo_account.source_description, "Venmo Account: venmojoe")
+        self.assertEqual("venmojoe", venmo_account.username)
+        self.assertEqual("Venmo-Joe-1", venmo_account.venmo_user_id)
+        self.assertEqual("Venmo Account: venmojoe", venmo_account.source_description)
         self.assertRegexpMatches(venmo_account.image_url, r"\.png")
-        self.assertEqual(venmo_account.customer_id, customer_id)
+        self.assertEqual(customer_id, venmo_account.customer_id)
 
+    def test_create_with_us_bank_account_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": TestHelper.generate_valid_us_bank_account_nonce()
+        })
+
+        self.assertTrue(result.is_success)
+        us_bank_account = result.payment_method
+        self.assertIsInstance(us_bank_account, UsBankAccount)
+        self.assertEqual(us_bank_account.routing_number, "021000021")
+        self.assertEqual(us_bank_account.last_4, "1234")
+        self.assertEqual(us_bank_account.account_type, "checking")
+        self.assertEqual(us_bank_account.account_description, "PayPal Checking - 1234")
+        self.assertEqual(us_bank_account.account_holder_name, "Dan Schulman")
+        self.assertTrue(re.match(r".*CHASE.*", us_bank_account.bank_name))
+
+    def test_create_fails_with_invalid_us_bank_account_nonce(self):
+        customer_id = Customer.create().customer.id
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": TestHelper.generate_invalid_us_bank_account_nonce()
+        })
+
+        self.assertFalse(result.is_success)
+        error_code = result.errors.for_object("payment_method").on("payment_method_nonce")[0].code
+        self.assertEqual(ErrorCodes.PaymentMethod.PaymentMethodNonceUnknown, error_code)
 
     def test_create_with_abstract_payment_method_nonce(self):
         customer_id = Customer.create().customer.id
@@ -277,6 +304,36 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertNotEqual(None, payment_method.token)
         self.assertEqual(customer_id, payment_method.customer_id)
 
+    def test_create_with_custom_card_verification_amount(self):
+        config = Configuration.instantiate()
+        customer_id = Customer.create().customer.id
+        client_token = json.loads(TestHelper.generate_decoded_client_token())
+        authorization_fingerprint = client_token["authorizationFingerprint"]
+        http = ClientApiHttp(config, {
+                    "authorization_fingerprint": authorization_fingerprint,
+                    "shared_customer_identifier": "fake_identifier",
+                    "shared_customer_identifier_type": "testing"
+                })
+        status_code, nonce = http.get_credit_card_nonce({
+            "number": "4000111111111115",
+            "expirationMonth": "11",
+            "expirationYear": "2099"
+        })
+        self.assertTrue(status_code == 201)
+
+        result = PaymentMethod.create({
+            "customer_id": customer_id,
+            "payment_method_nonce": nonce,
+            "options": {
+                "verify_card": "true",
+                "verification_amount": "1.02"
+            }
+        })
+
+        self.assertFalse(result.is_success)
+        verification = result.credit_card_verification
+        self.assertEqual(CreditCardVerification.Status.ProcessorDeclined, verification.status)
+
     def test_create_respects_verify_card_and_verification_merchant_account_id_when_outside_nonce(self):
         config = Configuration.instantiate()
         customer_id = Customer.create().customer.id
@@ -537,7 +594,7 @@ class TestPaymentMethod(unittest.TestCase):
 
         found_payment_method = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_payment_method)
-        self.assertEqual(result.payment_method.token, found_payment_method.token)
+        self.assertEqual(found_payment_method.token, result.payment_method.token)
 
     def test_find_returns_a_paypal_account(self):
         customer_id = Customer.create().customer.id
@@ -549,8 +606,8 @@ class TestPaymentMethod(unittest.TestCase):
 
         found_account = PaymentMethod.find(result.payment_method.token)
         self.assertNotEqual(None, found_account)
-        self.assertEquals(found_account.__class__, PayPalAccount)
-        self.assertEquals(found_account.email, "jane.doe@example.com")
+        self.assertEqual(PayPalAccount, found_account.__class__)
+        self.assertEqual("jane.doe@example.com", found_account.email)
 
     def test_find_returns_a_credit_card(self):
         customer = Customer.create().customer
@@ -562,12 +619,11 @@ class TestPaymentMethod(unittest.TestCase):
             "cardholder_name": "John Doe"
         })
         self.assertTrue(result.is_success)
-        credit_card = result.credit_card
 
         found_credit_card = PaymentMethod.find(result.credit_card.token)
         self.assertNotEqual(None, found_credit_card)
-        self.assertEquals(found_credit_card.__class__, CreditCard)
-        self.assertEquals(found_credit_card.bin, "411111")
+        self.assertEqual(CreditCard, found_credit_card.__class__)
+        self.assertEqual("411111", found_credit_card.bin)
 
     def test_find_returns_an_android_pay_card(self):
         customer = Customer.create().customer
@@ -581,8 +637,8 @@ class TestPaymentMethod(unittest.TestCase):
 
         found_android_pay_card = PaymentMethod.find(android_pay_card.token)
         self.assertNotEqual(None, found_android_pay_card)
-        self.assertEquals(found_android_pay_card.__class__, AndroidPayCard)
-        self.assertEqual(android_pay_card.token, found_android_pay_card.token)
+        self.assertEqual(AndroidPayCard, found_android_pay_card.__class__)
+        self.assertEqual(found_android_pay_card.token, android_pay_card.token)
 
     def test_delete_deletes_a_credit_card(self):
         customer = Customer.create().customer
@@ -793,7 +849,7 @@ class TestPaymentMethod(unittest.TestCase):
             }
         })
         update_result = PaymentMethod.update(credit_card_result.credit_card.token, {
-            "options": { "verify_card": "false" },
+            "options": {"verify_card": "false"},
             "billing_address": {
                 "first_name": "New First Name",
                 "last_name": "New Last Name",
@@ -832,7 +888,10 @@ class TestPaymentMethod(unittest.TestCase):
             "expiration_date": "05/2014",
         })
         self.assertFalse(update_result.is_success)
-        self.assertTrue(update_result.errors.for_object("credit_card").on("number")[0].message == "Credit card number must be 12-19 digits.")
+
+        number_errors = update_result.errors.for_object("credit_card").on("number")
+        self.assertEqual(1, len(number_errors))
+        self.assertEqual("Credit card number must be 12-19 digits.", number_errors[0].message)
 
     def test_update_can_update_the_default(self):
         customer_id = Customer.create().customer.id
@@ -847,15 +906,15 @@ class TestPaymentMethod(unittest.TestCase):
             "expiration_date": "05/2009"
         }).credit_card
 
-        self.assertTrue(card1.default == True)
-        self.assertTrue(card2.default == False)
+        self.assertTrue(card1.default)
+        self.assertFalse(card2.default)
 
-        update_result = PaymentMethod.update(card2.token, {
-            "options": { "make_default": True }
+        PaymentMethod.update(card2.token, {
+            "options": {"make_default": True}
         })
 
-        self.assertTrue(CreditCard.find(card1.token).default == False)
-        self.assertTrue(CreditCard.find(card2.token).default == True)
+        self.assertFalse(CreditCard.find(card1.token).default)
+        self.assertTrue(CreditCard.find(card2.token).default)
 
     def test_update_updates_a_paypal_accounts_token(self):
         customer_id = Customer.create().customer.id
@@ -869,8 +928,8 @@ class TestPaymentMethod(unittest.TestCase):
              "customer_id": customer_id
         })
 
-        updated_token = "UPDATED_TOKEN-" + str(randint(0,100000000))
-        updated_result = PaymentMethod.update(
+        updated_token = "UPDATED_TOKEN-" + str(random.randint(0, 100000000))
+        PaymentMethod.update(
             original_token,
             {"token": updated_token}
         )
@@ -897,24 +956,24 @@ class TestPaymentMethod(unittest.TestCase):
              "customer_id": customer_id
         }).payment_method.token
 
-        updated_result = PaymentMethod.update(
+        PaymentMethod.update(
             original_token,
             {"options": {"make_default": "true"}}
         )
 
         updated_paypal_account = PayPalAccount.find(original_token)
-        self.assertTrue(updated_paypal_account.default == True)
+        self.assertTrue(updated_paypal_account.default)
 
-    def test_update_updates_a_paypal_accounts_token(self):
+    def test_update_fails_to_updates_a_paypal_accounts_token_with(self):
         customer_id = Customer.create().customer.id
-        first_token = "paypal-account-" + str(randint(0,100000000))
-        second_token = "paypal-account-" + str(randint(0,100000000))
+        first_token = "paypal-account-" + str(random.randint(0, 100000000))
+        second_token = "paypal-account-" + str(random.randint(0, 100000000))
 
         first_nonce = TestHelper.nonce_for_paypal_account({
             "consent_code": "consent-code",
             "token": first_token
         })
-        first_result = PaymentMethod.create({
+        PaymentMethod.create({
              "payment_method_nonce": first_nonce,
              "customer_id": customer_id
         })
@@ -923,7 +982,7 @@ class TestPaymentMethod(unittest.TestCase):
             "consent_code": "consent-code",
             "token": second_token
         })
-        second_result = PaymentMethod.create({
+        PaymentMethod.create({
              "payment_method_nonce": second_nonce,
              "customer_id": customer_id
         })
@@ -933,11 +992,14 @@ class TestPaymentMethod(unittest.TestCase):
             {"token": second_token}
         )
 
-        self.assertTrue(updated_result.is_success == False)
-        self.assertTrue(updated_result.errors.deep_errors[0].code == "92906")
+        self.assertFalse(updated_result.is_success)
+
+        errors = updated_result.errors.deep_errors
+        self.assertEqual(1, len(errors))
+        self.assertEqual("92906", errors[0].code)
 
     def test_payment_method_grant_raises_on_non_existent_tokens(self):
-        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        granting_gateway, _ = TestHelper.create_payment_method_grant_fixtures()
         self.assertRaises(NotFoundError, granting_gateway.payment_method.grant, "non-existant-token", False)
 
     def test_payment_method_grant_returns_one_time_nonce(self):
@@ -945,7 +1007,7 @@ class TestPaymentMethod(unittest.TestCase):
         Payment method grant returns a nonce that is transactable by a partner merchant exactly once
         """
         granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
-        grant_result = granting_gateway.payment_method.grant(credit_card.token, False)
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, { "allow_vaulting": False });
         self.assertTrue(grant_result.is_success)
 
         result = Transaction.sale({
@@ -972,7 +1034,7 @@ class TestPaymentMethod(unittest.TestCase):
 
     def test_payment_method_grant_returns_a_nonce_that_is_vaultable(self):
         granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
-        grant_result = granting_gateway.payment_method.grant(credit_card.token, True)
+        grant_result = granting_gateway.payment_method.grant(credit_card.token, { "allow_vaulting": True })
         customer_id = Customer.create().customer.id
 
         result = PaymentMethod.create({
@@ -983,7 +1045,7 @@ class TestPaymentMethod(unittest.TestCase):
 
     def test_payment_method_revoke_renders_a_granted_nonce_unusable(self):
         granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
-        grant_result = granting_gateway.payment_method.grant(credit_card.token, False)
+        grant_result = granting_gateway.payment_method.grant(credit_card.token)
 
         revoke_result = granting_gateway.payment_method.revoke(credit_card.token)
         self.assertTrue(revoke_result.is_success)
@@ -995,7 +1057,7 @@ class TestPaymentMethod(unittest.TestCase):
         self.assertFalse(result.is_success)
 
     def test_payment_method_revoke_raises_on_non_existent_tokens(self):
-        granting_gateway, credit_card = TestHelper.create_payment_method_grant_fixtures()
+        granting_gateway, _ = TestHelper.create_payment_method_grant_fixtures()
         self.assertRaises(NotFoundError, granting_gateway.payment_method.revoke, "non-existant-token")
 
 class CreditCardForwardingTest(unittest.TestCase):
