@@ -1,21 +1,25 @@
+import json
 import os
-import random
 import re
-import unittest
+import random
 import sys
+import unittest
+import warnings
+import subprocess
+
 if sys.version_info[0] == 2:
     from urllib import urlencode, quote_plus
     from httplib import HTTPConnection
 else:
     from urllib.parse import urlencode, quote_plus
     from http.client import HTTPConnection
-import warnings
-import json
+import requests
+
 from base64 import b64decode
 from contextlib import contextmanager
 from datetime import date, datetime, timedelta
 from decimal import Decimal
-from random import randint
+from subprocess import Popen, PIPE
 
 from nose.tools import make_decorator
 from nose.tools import raises
@@ -57,7 +61,7 @@ def reset_braintree_configuration():
     )
 reset_braintree_configuration()
 
-def showwarning(message, category, filename, lineno, file=None, line=None):
+def showwarning(*_):
     pass
 warnings.showwarning = showwarning
 
@@ -101,6 +105,10 @@ class TestHelper(object):
         "trial_period": False
     }
 
+    valid_token_characters = list("bcdfghjkmnpqrstvwxyz23456789")
+    text_type = unicode if sys.version_info[0] == 2 else str
+    raw_type = str if sys.version_info[0] == 2 else bytes
+
     @staticmethod
     def make_past_due(subscription, number_of_days_past_due=1):
         Configuration.gateway().testing.make_past_due(subscription.id, number_of_days_past_due)
@@ -184,8 +192,8 @@ class TestHelper(object):
         return (now - timedelta(hours=offset)).strftime("%Y-%m-%d")
 
     @staticmethod
-    def unique(list):
-        return set(list)
+    def unique(some_list):
+        return set(some_list)
 
     @staticmethod
     def __headers():
@@ -207,14 +215,58 @@ class TestHelper(object):
 
     @staticmethod
     def nonce_for_paypal_account(paypal_account_details):
-        client_token =json.loads(TestHelper.generate_decoded_client_token())
+        client_token = json.loads(TestHelper.generate_decoded_client_token())
         client = ClientApiHttp(Configuration.instantiate(), {
             "authorization_fingerprint": client_token["authorizationFingerprint"]
         })
 
-        status_code, nonce = client.get_paypal_nonce(paypal_account_details)
+        _, nonce = client.get_paypal_nonce(paypal_account_details)
         return nonce
 
+    @staticmethod
+    def random_token_block(x):
+        string = ""
+        for i in range(6):
+            string += random.choice(TestHelper.valid_token_characters)
+        return string
+
+    @staticmethod
+    def generate_valid_us_bank_account_nonce():
+        client_token = json.loads(TestHelper.generate_decoded_client_token())
+        headers = {
+            "Content-Type": "application/json",
+            "Braintree-Version": "2015-11-01",
+            "Authorization": "Bearer " + client_token["braintree_api"]["access_token"]
+        }
+        payload = {
+            "type": "us_bank_account",
+            "billing_address": {
+                "street_address": "123 Ave",
+                "region": "CA",
+                "locality": "San Francisco",
+                "postal_code": "94112"
+            },
+            "account_type": "checking",
+            "routing_number": "021000021",
+            "account_number": "567891234",
+            "account_holder_name": "Dan Schulman",
+            "account_description": "PayPal Checking - 1234",
+            "ach_mandate": {
+                "text": ""
+            }
+        }
+        resp = requests.post(client_token["braintree_api"]["url"] + "/tokens", headers=headers, data=json.dumps(payload) )
+        respJson = json.loads(resp.text)
+        return respJson["data"]["id"]
+
+    @staticmethod
+    def generate_invalid_us_bank_account_nonce():
+        token = "tokenusbankacct"
+        for i in range(4):
+            token += "_" + TestHelper.random_token_block('d')
+        token += "_xxx"
+        return token
+
     @staticmethod
     def create_grant(gateway, params):
         config = gateway.config
@@ -227,26 +279,31 @@ class TestHelper(object):
     @staticmethod
     def create_payment_method_grant_fixtures():
         config = Configuration(
-            merchant_id = "integration_merchant_public_id",
-            public_key = "oauth_app_partner_user_public_key",
-            private_key = "oauth_app_partner_user_private_key",
-            environment = Environment.Development
+            merchant_id="integration_merchant_public_id",
+            public_key="oauth_app_partner_user_public_key",
+            private_key="oauth_app_partner_user_private_key",
+            environment=Environment.Development
         )
 
         gateway = BraintreeGateway(config)
         customer = gateway.customer.create().customer
         credit_card = gateway.credit_card.create(
-            params = {
+            params={
                 "customer_id": customer.id,
                 "number": "4111111111111111",
                 "expiration_date": "05/2009",
+                "billing_address": {
+                    "first_name": "Jon",
+                    "last_name": "Doe",
+                    "postal_code": "95131"
+                }
             }
         ).credit_card
 
         oauth_app_gateway = BraintreeGateway(
-            client_id = "client_id$development$integration_client_id",
-            client_secret = "client_secret$development$integration_client_secret",
-            environment = Environment.Development
+            client_id="client_id$development$integration_client_id",
+            client_secret="client_secret$development$integration_client_secret",
+            environment=Environment.Development
         )
         code = TestHelper.create_grant(oauth_app_gateway, {
             "merchant_public_id": "integration_merchant_id",
@@ -257,7 +314,7 @@ class TestHelper(object):
         }).credentials.access_token
 
         granting_gateway = BraintreeGateway(
-            access_token = access_token,
+            access_token=access_token,
         )
 
         return (granting_gateway, credit_card)
@@ -283,10 +340,10 @@ class ClientApiHttp(Http):
     def get(self, path):
         return self.__http_do("GET", path)
 
-    def post(self, path, params = None):
+    def post(self, path, params=None):
         return self.__http_do("POST", path, params)
 
-    def put(self, path, params = None):
+    def put(self, path, params=None):
         return self.__http_do("PUT", path, params)
 
     def __http_do(self, http_verb, path, params=None):
@@ -357,9 +414,8 @@ class ClientApiHttp(Http):
 
         status_code, response = self.post(url, params)
         json_body = json.loads(response)
-        mandate_reference_number = json_body["europeBankAccounts"][0]["sepaMandates"][0]["mandateReferenceNumber"]
-        nonce = None
 
+        nonce = None
         if status_code == 201:
             nonce = json_body["europeBankAccounts"][0]["nonce"]
 
