@@ -1,6 +1,5 @@
 from tests.test_helper import *
 import datetime
-import braintree.test.venmo_sdk as venmo_sdk
 
 class TestCreditCard(unittest.TestCase):
     @raises_with_regexp(KeyError, "'Invalid keys: bad_key'")
@@ -21,14 +20,14 @@ class TestCreditCard(unittest.TestCase):
 
     def test_transparent_redirect_create_url(self):
         port = os.getenv("GATEWAY_PORT") or "3000"
-        self.assertEquals(
+        self.assertEqual(
             "http://localhost:" + port + "/merchants/integration_merchant_id/payment_methods/all/create_via_transparent_redirect_request",
             CreditCard.transparent_redirect_create_url()
         )
 
     def test_transparent_redirect_update_url(self):
         port = os.getenv("GATEWAY_PORT") or "3000"
-        self.assertEquals(
+        self.assertEqual(
             "http://localhost:" + port + "/merchants/integration_merchant_id/payment_methods/all/update_via_transparent_redirect_request",
             CreditCard.transparent_redirect_update_url()
         )
@@ -49,10 +48,11 @@ class TestCreditCard(unittest.TestCase):
                     "extended_address", "first_name", "last_name", "locality", "postal_code", "region", "street_address"
                 ]
             },
-            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session", "fail_on_duplicate_payment_method"]},
+            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
+            ]},
             "customer_id"
         ]
-        self.assertEquals(expected, CreditCard.create_signature())
+        self.assertEqual(expected, CreditCard.create_signature())
 
     def test_update_signature(self):
         expected = ["billing_address_id", "cardholder_name", "cvv", "expiration_date", "expiration_month",
@@ -65,9 +65,10 @@ class TestCreditCard(unittest.TestCase):
                     {"options": ["update_existing"]}
                 ]
             },
-            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session"]}
+            {"options": ["make_default", "verification_merchant_account_id", "verify_card", "verification_amount", "venmo_sdk_session", "fail_on_duplicate_payment_method", {"adyen":["overwrite_brand", "selected_brand"]}
+            ]}
         ]
-        self.assertEquals(expected, CreditCard.update_signature())
+        self.assertEqual(expected, CreditCard.update_signature())
 
     @raises(NotFoundError)
     def test_finding_empty_id_raises_not_found_exception(self):
@@ -81,4 +82,4 @@ class TestCreditCard(unittest.TestCase):
         verification1 = {"created_at": datetime.datetime(2014, 11, 18, 23, 20, 20), "id":123}
         verification2 = {"created_at": datetime.datetime(2014, 11, 18, 23, 20, 21), "id":456}
         credit_card = CreditCard(Configuration.gateway(), {"verifications": [verification1, verification2]})
-        self.assertEquals(credit_card.verification.id, 456)
+        self.assertEqual(456, credit_card.verification.id)
