@@ -24,13 +24,13 @@ class TestDispute(unittest.TestCase):
 
         dispute = Dispute(attributes)
 
-        self.assertEquals(dispute.id, "123456")
-        self.assertEquals(dispute.amount, Decimal("100.00"))
-        self.assertEquals(dispute.currency_iso_code, "USD")
-        self.assertEquals(dispute.reason, Dispute.Reason.Fraud)
-        self.assertEquals(dispute.status, Dispute.Status.Open)
-        self.assertEquals(dispute.transaction_details.id, "transaction_id")
-        self.assertEquals(dispute.transaction_details.amount, Decimal("100.00"))
-        self.assertEquals(dispute.date_opened, date(2013, 4, 1))
-        self.assertEquals(dispute.date_won, date(2013, 4, 2))
-        self.assertEquals(dispute.kind, Dispute.Kind.Chargeback)
+        self.assertEqual(dispute.id, "123456")
+        self.assertEqual(dispute.amount, Decimal("100.00"))
+        self.assertEqual(dispute.currency_iso_code, "USD")
+        self.assertEqual(dispute.reason, Dispute.Reason.Fraud)
+        self.assertEqual(dispute.status, Dispute.Status.Open)
+        self.assertEqual(dispute.transaction_details.id, "transaction_id")
+        self.assertEqual(dispute.transaction_details.amount, Decimal("100.00"))
+        self.assertEqual(dispute.date_opened, date(2013, 4, 1))
+        self.assertEqual(dispute.date_won, date(2013, 4, 2))
+        self.assertEqual(dispute.kind, Dispute.Kind.Chargeback)
